@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Base;
 
-our $DATE = '2015-06-30'; # DATE
-our $VERSION = '1.17'; # VERSION
+our $DATE = '2015-07-06'; # DATE
+our $VERSION = '1.18'; # VERSION
 
 use 5.010001;
 use strict;
@@ -1224,7 +1224,8 @@ sub run {
         $r->{res}[2] = $r->{res}[3]{'cmdline.result'};
     }
   FORMAT:
-    if ($r->{res}[3]{'cmdline.skip_format'}) {
+    if ($r->{meta}{'cmdline.skip_format'} ||
+            $r->{res}[3]{'cmdline.skip_format'}) {
         $r->{fres} = $r->{res}[2];
     } elsif ($r->{res}[3]{stream} // $r->{meta}{result}{stream}) {
         # stream will be formatted as displayed by display_result()
@@ -1274,7 +1275,7 @@ Perinci::CmdLine::Base - Base class for Perinci::CmdLine{::Classic,::Lite}
 
 =head1 VERSION
 
-This document describes version 1.17 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-06-30.
+This document describes version 1.18 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-07-06.
 
 =head1 DESCRIPTION
 
@@ -1377,8 +1378,9 @@ C<hook_after_action> is then called e.g. to preformat result.
 
 Hook must set C<< $r->{fres} >> (formatted result).
 
-If result has C<cmdline.skip_format> result metadata property, then this step is
-skipped and C<< $r->{fres} >> is simply taken from C<< $r->{res}[2] >>.
+If function metadata has C<cmdline.skip_format> or result has
+C<cmdline.skip_format> result metadata property, then this step is skipped and
+C<< $r->{fres} >> is simply taken from C<< $r->{res}[2] >>.
 
 =item * Run hook_display_result
 
@@ -2074,6 +2076,12 @@ This module observes the following Rinci metadata property attributes:
 Set default output format (if user does not specify via --format command-line
 option).
 
+=head2 cmdline.skip_format => bool
+
+If you set it to 1, you specify that function's result never needs formatting
+(i.e. the function outputs raw text to be outputted directly), so no formatting
+will be done. See also: C<cmdline.skip_format> result metadata.
+
 =head1 RESULT METADATA
 
 This module interprets the following result metadata property/attribute:
@@ -2153,7 +2161,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Cm
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Perinci-CmdLine-Lite>.
+Source repository is at L<https://github.com/sharyanto/perl-Perinci-CmdLine-Lite>.
 
 =head1 BUGS
 
